==> nextcloud-17.0.6.zip: nextcloud/apps/privacy/l10n/bg.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Защита на лични данни",
    "-" : "-",
    "This server is protected with full-disk-encryption." : "Този сървър е криптиран",
    "Your data is located in: " : "Вашите данни се съхраняват в:",
    "Somaliland" : "Сомалиленд",
    "Andorra" : "Андора",
    "United Arab Emirates" : "Обединени арабски емирства",
    "Afghanistan" : "Афганистан",
    "Antigua and Barbuda" : "Антигуа и Барбуда",
    "Anguilla" : "Ангила",
    "Albania" : "Албания",
    "Armenia" : "Армения",
    "Angola" : "Ангола",
    "Antarctica" : "Антарктида",
    "Argentina" : "Аржентина",
    "American Samoa" : "Американска Самоа",
    "Austria" : "Австрия",
    "Australia" : "Австралия",
    "Aruba" : "Аруба",
    "Åland Islands" : "Оландски острови",
    "Azerbaijan" : "Азербайджан",
    "Bosnia and Herzegovina" : "Босна и Херцеговина",
    "Barbados" : "Барбадос",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Белгия",
    "Burkina Faso" : "Буркина Фасо",
    "Bulgaria" : "България",
    "Bahrain" : "Бахрейн",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Saint Barthélemy" : "Сен Бартелеми",
    "Bermuda" : "Бермуда",
    "Brunei" : "Бруней",
    "Bolivia" : "Боливия",
    "Brazil" : "Бразилия",
    "Bahamas" : "Бахамски острови",
    "Bhutan" : "Бутан",
    "Bouvet Island" : "остров Буве",
    "Botswana" : "Ботсуана",
    "Belarus" : "Беларус",
    "Belize" : "Белийз",
    "Canada" : "Канада",
    "Cocos (Keeling) Islands" : "Кокосови строви (Кийлинг)",
    "Democratic Republic of the Congo" : "Демократична република Конго",
    "Central African Republic" : "Централноафриканска република",
    "Congo" : "Конго",
    "Switzerland" : "Швейцария",
    "Cote d'Ivoire" : "Кот д’Ивоар",
    "Cook Islands" : "Oстрови Кук",
    "Chile" : "Чили",
    "Cameroon" : "Камерун",
    "China" : "Китай",
    "Colombia" : "Колумбия",
    "Costa Rica" : "Коста Рика",
    "Cuba" : "Куба",
    "Cabo Verde" : "Кабо Верде",
    "Curaçao" : "Кюрасао",
    "Christmas Island" : "остров Рождество",
    "Cyprus" : "Кипър",
    "Czech" : "чешки",
    "Germany" : "Германия",
    "Djibouti" : "Джибути",
    "Denmark" : "Дания",
    "Dominican Republic" : "Доминиканска република",
    "Algeria" : "Алжир",
    "Ecuador" : "Еквадор",
    "Estonia" : "Естония",
    "Egypt" : "Египет",
    "West Sahara" : "Западна Сахара",
    "Eritrea" : "Еритрея",
    "Spain" : "Испания",
    "Ethiopia" : "Етиопия",
    "Finland" : "Финландия",
    "Fiji" : "Фиджи",
    "Falkland Islands" : "Оландски острови",
    "Faroe Islands" : "Фарьорски острови",
    "France" : "Франция",
    "Gabon" : "Габон",
    "United Kingdom" : "Обединено кралство",
    "Grenada" : "Гренада",
    "Georgia" : "Грузия",
    "French Guiana" : "Френска Гвиана",
    "Guernsey" : "Гърнзи",
    "Ghana" : "Гана",
    "Gibraltar" : "Гибралтар",
    "Greenland" : "Гренландия",
    "Gambia" : "Гамбия",
    "Guinea" : "Гвинея",
    "Guadeloupe" : "Гваделупа",
    "Equatorial Guinea" : "Екваториална Гвинея",
    "Greece" : "Гърция",
    "South Georgia and the South Sandwich Islands" : "Южна Джорджия и Южни Сандвичеви острови",
    "Guatemala" : "Гватемала",
    "Guam" : "Гуам",
    "Guinea-Bissau" : "Гвинея Бисау",
    "Guyana" : "Гвиaна",
    "Honduras" : "Хондурас",
    "Hong Kong" : "Хонконг",
    "Heard Island and McDonald Islands" : "Хърд и Макдоналд",
    "Croatia" : "Хърватия",
    "Haiti" : "Хаити",
    "Hungary" : "Унгария",
    "Indonesia" : "Индонезия",
    "Ireland" : "Ирландия",
    "Israel" : "Израел",
    "Isle of Man" : "Остров Ман",
    "India" : "Индия",
    "British Indian Ocean Territory" : "Британска индоокеанска територия",
    "Iraq" : "Ирак",
    "Iran" : "Иран",
    "Iceland" : "Исландия",
    "Italy" : "Италия",
    "Jamaica" : "Ямайка",
    "Jordan" : "Йордания",
    "Japan" : "Япония",
    "Kenya" : "Кения",
    "Kyrgyzstan" : "Киргизстан",
    "Cambodia" : "Камбоджа",
    "Kiribati" : "Кирибати",
    "Saint Kitts and Nevis" : "Сейнт Китс и Невис",
    "North Korea" : "Северна Корея",
    "South Korea" : "Северна Корея",
    "Kuwait" : "Кувейт",
    "Cayman Islands" : "Кайманови острови",
    "Kazakhstan" : "Казахстан",
    "Laos" : "лаоски",
    "Lebanon" : "Ливан",
    "Saint Lucia" : "Сейнт Лусия",
    "Liechtenstein" : "Лихтенщайн",
    "Sri Lanka" : "Шри Ланка",
    "Liberia" : "Либерия",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литва",
    "Luxembourg" : "Люксембург",
    "Latvia" : "Латвия",
    "Libya" : "Либия",
    "Morocco" : "Мароко",
    "Monaco" : "Монако",
    "Moldova" : "Молдова",
    "Montenegro" : "Черна гора",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршалови острови",
    "Mali" : "Мали",
    "Myanmar" : "Мианмар",
    "Mongolia" : "Монголия",
    "Macao" : "Макао",
    "Northern Mariana Islands" : "Северни Мариански острови",
    "Mauritania" : "Мавритания",
    "Montserrat" : "Монсерат",
    "Malta" : "Малта",
    "Mauritius" : "Мавриций",
    "Maldives" : "Малдиви",
    "Malawi" : "Малави",
    "Mexico" : "Мексико",
    "Malaysia" : "Малайзия",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намибия",
    "New Caledonia" : "Нова Каледония",
    "Niger" : "Нигер",
    "Norfolk Island" : "Oстров Норфолк",
    "Nigeria" : "Нигерия",
    "Nicaragua" : "Никарагуа",
    "Netherlands" : "Нидерландия",
    "Norway" : "Норвегия",
    "Nepal" : "Непал",
    "Nauru" : "Науру",
    "Niue" : "Ниуе",
    "New Zealand" : "Нова Зеландия",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "French Polynesia" : "Френска Полинезия",
    "Papua New Guinea" : "Папуа Нова Гвинея",
    "Philippines" : "Филипини",
    "Pakistan" : "Пакистан",
    "Poland" : "Полша",
    "Saint Pierre and Miquelon" : "Сен Пиер и Микелон",
    "Pitcairn" : "Oстрови Питкерн",
    "Puerto Rico" : "Пуерто Рико",
    "Portugal" : "Португалия",
    "Palau" : "Палау",
    "Paraguay" : "Парагвай",
    "Qatar" : "Катар",
    "Réunion" : "Реюнион",
    "Romania" : "Румъния",
    "Serbia" : "Сърбия",
    "Russia" : "Русия",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудитска Арабия",
    "Solomon Islands" : "Соломонови острови",
    "Seychelles" : "Сейшелски острови",
    "Sudan" : "Судан",
    "Sweden" : "Швеция",
    "Singapore" : "Сингапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "Света Елена, Възнесение и Тристан да Куня",
    "Slovenia" : "Словения",
    "Svalbard and Jan Mayen" : "Свалбард и Ян Майен",
    "Slovakia" : "Словакия",
    "Sierra Leone" : "Сиера Леоне",
    "San Marino" : "Сан Марино",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомалия",
    "Suriname" : "Суринам",
    "South Sudan" : "Южен Судан",
    "Sao Tome and Principe" : "Сао Томе и Принсипи",
    "El Salvador" : "Ел Салвадор",
    "Syria" : "Сирия",
    "Swaziland" : "Свазиленд",
    "Turks and Caicos Islands" : "Търкс и Кайкос",
    "Chad" : "Чад",
    "Fr. S. Antarctic Lands" : "Френски южни и антарктически територии",
    "Togo" : "Того",
    "Thailand" : "Тайланд",
    "Tajikistan" : "Таджикистан",
    "Tokelau" : "Токелау",
    "Timor-Leste" : "Източен Тимор",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Tonga" : "Тонга",
    "Turkey" : "Турция",
    "Trinidad and Tobago" : "Тринидад и Тобаго",
    "Tuvalu" : "Тувалу",
    "Taiwan" : "Тайван",
    "Tanzania" : "Танзания",
    "Ukraine" : "Украйна",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "Малки отдалечени острови на Съединените щати",
    "Uruguay" : "Уругвай",
    "Uzbekistan" : "Узбекистан",
    "Holy See" : "Свети престол",
    "Saint Vincent and the Grenadines" : "Сейнт Винсънт и Гренадини",
    "Venezuela" : "Венецуела",
    "Virgin Islands (British)" : "Британски Вирджински острови",
    "Virgin Islands (U.S.)" : "Американски Вирджински острови",
    "Vietnam" : "Виетнам",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Уолис и Футуна",
    "Samoa" : "Самоа",
    "Yemen" : "Йемен",
    "Mayotte" : "Майот",
    "South Africa" : "Южна Африка",
    "Zambia" : "Замбия",
    "Zimbabwe" : "Зимбабве",
    "Control" : "Control Center",
    "Learn more ↗" : "Научете повече ↗",
    "Where is your data?" : "Къде е информацията ви?",
    "Who has access to your data?" : "Кой има достъп до информацията?",
    "Administrators" : "Администратори",
    "People you shared with" : "Хора с които е споделено",
    "Encryption" : "Криптиране",
    "Please select a country" : "Моля изберете държава",
    "Bosnia and Herzegowina" : "Босна и Херцеговина"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.7.zip: nextcloud/apps/privacy/l10n/bg.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Защита на лични данни",
    "-" : "-",
    "This server is protected with full-disk-encryption." : "Този сървър е криптиран",
    "Your data is located in: " : "Вашите данни се съхраняват в:",
    "Somaliland" : "Сомалиленд",
    "Andorra" : "Андора",
    "United Arab Emirates" : "Обединени арабски емирства",
    "Afghanistan" : "Афганистан",
    "Antigua and Barbuda" : "Антигуа и Барбуда",
    "Anguilla" : "Ангила",
    "Albania" : "Албания",
    "Armenia" : "Армения",
    "Angola" : "Ангола",
    "Antarctica" : "Антарктида",
    "Argentina" : "Аржентина",
    "American Samoa" : "Американска Самоа",
    "Austria" : "Австрия",
    "Australia" : "Австралия",
    "Aruba" : "Аруба",
    "Åland Islands" : "Оландски острови",
    "Azerbaijan" : "Азербайджан",
    "Bosnia and Herzegovina" : "Босна и Херцеговина",
    "Barbados" : "Барбадос",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Белгия",
    "Burkina Faso" : "Буркина Фасо",
    "Bulgaria" : "България",
    "Bahrain" : "Бахрейн",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Saint Barthélemy" : "Сен Бартелеми",
    "Bermuda" : "Бермуда",
    "Brunei" : "Бруней",
    "Bolivia" : "Боливия",
    "Bonaire, Sint Eustatius and Saba" : "отвъдморски територии на Нидерландия",
    "Brazil" : "Бразилия",
    "Bahamas" : "Бахамски острови",
    "Bhutan" : "Бутан",
    "Bouvet Island" : "остров Буве",
    "Botswana" : "Ботсуана",
    "Belarus" : "Беларус",
    "Belize" : "Белийз",
    "Canada" : "Канада",
    "Cocos (Keeling) Islands" : "Кокосови строви (Кийлинг)",
    "Democratic Republic of the Congo" : "Демократична република Конго",
    "Central African Republic" : "Централноафриканска република",
    "Congo" : "Конго",
    "Switzerland" : "Швейцария",
    "Cote d'Ivoire" : "Кот д’Ивоар",
    "Cook Islands" : "Oстрови Кук",
    "Chile" : "Чили",
    "Cameroon" : "Камерун",
    "China" : "Китай",
    "Colombia" : "Колумбия",
    "Costa Rica" : "Коста Рика",
    "Cuba" : "Куба",
    "Cabo Verde" : "Кабо Верде",
    "Curaçao" : "Кюрасао",
    "Christmas Island" : "остров Рождество",
    "Cyprus" : "Кипър",
    "Czech" : "чешки",
    "Germany" : "Германия",
    "Djibouti" : "Джибути",
    "Denmark" : "Дания",
    "Dominican Republic" : "Доминиканска република",
    "Algeria" : "Алжир",
    "Ecuador" : "Еквадор",
    "Estonia" : "Естония",
    "Egypt" : "Египет",
    "West Sahara" : "Западна Сахара",
    "Eritrea" : "Еритрея",
    "Spain" : "Испания",
    "Ethiopia" : "Етиопия",
    "Finland" : "Финландия",
    "Fiji" : "Фиджи",
    "Falkland Islands" : "Оландски острови",
    "Faroe Islands" : "Фарьорски острови",
    "France" : "Франция",
    "Gabon" : "Габон",
    "United Kingdom" : "Обединено кралство",
    "Grenada" : "Гренада",
    "Georgia" : "Грузия",
    "French Guiana" : "Френска Гвиана",
    "Guernsey" : "Гърнзи",
    "Ghana" : "Гана",
    "Gibraltar" : "Гибралтар",
    "Greenland" : "Гренландия",
    "Gambia" : "Гамбия",
    "Guinea" : "Гвинея",
    "Guadeloupe" : "Гваделупа",
    "Equatorial Guinea" : "Екваториална Гвинея",
    "Greece" : "Гърция",
    "South Georgia and the South Sandwich Islands" : "Южна Джорджия и Южни Сандвичеви острови",
    "Guatemala" : "Гватемала",
    "Guam" : "Гуам",
    "Guinea-Bissau" : "Гвинея Бисау",
    "Guyana" : "Гвиaна",
    "Honduras" : "Хондурас",
    "Hong Kong" : "Хонконг",
    "Heard Island and McDonald Islands" : "Хърд и Макдоналд",
    "Croatia" : "Хърватия",
    "Haiti" : "Хаити",
    "Hungary" : "Унгария",
    "Indonesia" : "Индонезия",
    "Ireland" : "Ирландия",
    "Israel" : "Израел",
    "Isle of Man" : "Остров Ман",
    "India" : "Индия",
    "British Indian Ocean Territory" : "Британска индоокеанска територия",
    "Iraq" : "Ирак",
    "Iran" : "Иран",
    "Iceland" : "Исландия",
    "Italy" : "Италия",
    "Jamaica" : "Ямайка",
    "Jordan" : "Йордания",
    "Japan" : "Япония",
    "Kenya" : "Кения",
    "Kyrgyzstan" : "Киргизстан",
    "Cambodia" : "Камбоджа",
    "Kiribati" : "Кирибати",
    "Saint Kitts and Nevis" : "Сейнт Китс и Невис",
    "North Korea" : "Северна Корея",
    "South Korea" : "Северна Корея",
    "Kuwait" : "Кувейт",
    "Cayman Islands" : "Кайманови острови",
    "Kazakhstan" : "Казахстан",
    "Laos" : "лаоски",
    "Lebanon" : "Ливан",
    "Saint Lucia" : "Сейнт Лусия",
    "Liechtenstein" : "Лихтенщайн",
    "Sri Lanka" : "Шри Ланка",
    "Liberia" : "Либерия",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литва",
    "Luxembourg" : "Люксембург",
    "Latvia" : "Латвия",
    "Libya" : "Либия",
    "Morocco" : "Мароко",
    "Monaco" : "Монако",
    "Moldova" : "Молдова",
    "Montenegro" : "Черна гора",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршалови острови",
    "Mali" : "Мали",
    "Myanmar" : "Мианмар",
    "Mongolia" : "Монголия",
    "Macao" : "Макао",
    "Northern Mariana Islands" : "Северни Мариански острови",
    "Mauritania" : "Мавритания",
    "Montserrat" : "Монсерат",
    "Malta" : "Малта",
    "Mauritius" : "Мавриций",
    "Maldives" : "Малдиви",
    "Malawi" : "Малави",
    "Mexico" : "Мексико",
    "Malaysia" : "Малайзия",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намибия",
    "New Caledonia" : "Нова Каледония",
    "Niger" : "Нигер",
    "Norfolk Island" : "Oстров Норфолк",
    "Nigeria" : "Нигерия",
    "Nicaragua" : "Никарагуа",
    "Netherlands" : "Нидерландия",
    "Norway" : "Норвегия",
    "Nepal" : "Непал",
    "Nauru" : "Науру",
    "Niue" : "Ниуе",
    "New Zealand" : "Нова Зеландия",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "French Polynesia" : "Френска Полинезия",
    "Papua New Guinea" : "Папуа Нова Гвинея",
    "Philippines" : "Филипини",
    "Pakistan" : "Пакистан",
    "Poland" : "Полша",
    "Saint Pierre and Miquelon" : "Сен Пиер и Микелон",
    "Pitcairn" : "Oстрови Питкерн",
    "Puerto Rico" : "Пуерто Рико",
    "Portugal" : "Португалия",
    "Palau" : "Палау",
    "Paraguay" : "Парагвай",
    "Qatar" : "Катар",
    "Réunion" : "Реюнион",
    "Romania" : "Румъния",
    "Serbia" : "Сърбия",
    "Russia" : "Русия",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудитска Арабия",
    "Solomon Islands" : "Соломонови острови",
    "Seychelles" : "Сейшелски острови",
    "Sudan" : "Судан",
    "Sweden" : "Швеция",
    "Singapore" : "Сингапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "Света Елена, Възнесение и Тристан да Куня",
    "Slovenia" : "Словения",
    "Svalbard and Jan Mayen" : "Свалбард и Ян Майен",
    "Slovakia" : "Словакия",
    "Sierra Leone" : "Сиера Леоне",
    "San Marino" : "Сан Марино",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомалия",
    "Suriname" : "Суринам",
    "South Sudan" : "Южен Судан",
    "Sao Tome and Principe" : "Сао Томе и Принсипи",
    "El Salvador" : "Ел Салвадор",
    "Syria" : "Сирия",
    "Swaziland" : "Свазиленд",
    "Turks and Caicos Islands" : "Търкс и Кайкос",
    "Chad" : "Чад",
    "Fr. S. Antarctic Lands" : "Френски южни и антарктически територии",
    "Togo" : "Того",
    "Thailand" : "Тайланд",
    "Tajikistan" : "Таджикистан",
    "Tokelau" : "Токелау",
    "Timor-Leste" : "Източен Тимор",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Tonga" : "Тонга",
    "Turkey" : "Турция",
    "Trinidad and Tobago" : "Тринидад и Тобаго",
    "Tuvalu" : "Тувалу",
    "Taiwan" : "Тайван",
    "Tanzania" : "Танзания",
    "Ukraine" : "Украйна",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "Малки отдалечени острови на Съединените щати",
    "Uruguay" : "Уругвай",
    "Uzbekistan" : "Узбекистан",
    "Holy See" : "Свети престол",
    "Saint Vincent and the Grenadines" : "Сейнт Винсънт и Гренадини",
    "Venezuela" : "Венецуела",
    "Virgin Islands (British)" : "Британски Вирджински острови",
    "Virgin Islands (U.S.)" : "Американски Вирджински острови",
    "Vietnam" : "Виетнам",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Уолис и Футуна",
    "Samoa" : "Самоа",
    "Yemen" : "Йемен",
    "Mayotte" : "Майот",
    "South Africa" : "Южна Африка",
    "Zambia" : "Замбия",
    "Zimbabwe" : "Зимбабве",
    "Control" : "Control Center",
    "Learn more ↗" : "Научете повече ↗",
    "Where is your data?" : "Къде е информацията ви?",
    "Who has access to your data?" : "Кой има достъп до информацията?",
    "Administrators" : "Администратори",
    "People you shared with" : "Хора с които е споделено",
    "Encryption" : "Криптиране"
},
"nplurals=2; plural=(n != 1);");
